@@ -4,27 +4,38 @@ can be used as a standalone window or in a larger GUI.
 """
 
 import sys
+import time
 import ctypes
 import importlib
 
 from .base import WgpuCanvasBase
 
 # Select GUI toolkit
-for libname in ("PySide2", "PyQt5", "PySide", "PyQt4"):
+for libname in ("PySide6", "PyQt6", "PySide2", "PyQt5", "PySide", "PyQt4"):
     if libname in sys.modules:
         QtCore = importlib.import_module(libname + ".QtCore")
         widgets_modname = "QtGui" if QtCore.qVersion()[0] == "4" else "QtWidgets"
         QtWidgets = importlib.import_module(libname + "." + widgets_modname)
+        try:
+            WA_PaintOnScreen = QtCore.Qt.WidgetAttribute.WA_PaintOnScreen
+            PreciseTimer = QtCore.Qt.TimerType.PreciseTimer
+        except AttributeError:
+            WA_PaintOnScreen = QtCore.Qt.WA_PaintOnScreen
+            PreciseTimer = QtCore.Qt.PreciseTimer
         break
 else:
     raise ImportError(
         "Import one of PySide2, PyQt5 before the WgpuCanvas to select a Qt toolkit"
     )
 
+# Make Qt not ignore XDG_SESSION_TYPE
+# is_wayland = "wayland" in os.getenv("XDG_SESSION_TYPE", "").lower()
+# if is_wayland:
+#     os.environ["QT_QPA_PLATFORM"] = "wayland"
+
 
 def enable_hidpi():
-    """ Enable high-res displays.
-    """
+    """Enable high-res displays."""
     try:
         # See https://github.com/pyzo/pyzo/pull/700 why we seem to need both
         ctypes.windll.shcore.SetProcessDpiAwareness(1)  # global dpi aware
@@ -45,6 +56,8 @@ enable_hidpi()
 
 
 class QtWgpuCanvas(WgpuCanvasBase, QtWidgets.QWidget):
+    """A Qt widget providing a wgpu canvas."""
+
     def __init__(self, *args, size=None, title=None, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -67,6 +80,13 @@ class QtWgpuCanvas(WgpuCanvasBase, QtWidgets.QWidget):
         self.setLayout(layout)
         layout.addWidget(self._subwidget)
 
+        # A timer for limiting fps
+        self._target_fps = 30  # subclasses could edit this value
+        self._request_draw_timer = QtCore.QTimer()
+        self._request_draw_timer.setTimerType(PreciseTimer)
+        self._request_draw_timer.setSingleShot(True)
+        self._request_draw_timer.timeout.connect(self.update)
+
         self.show()
 
     # Qt methods
@@ -86,8 +106,9 @@ class QtWgpuCanvas(WgpuCanvasBase, QtWidgets.QWidget):
         return int(self._subwidget.winId())
 
     def get_pixel_ratio(self):
-        # The pixel ratio always seems to be a whole number. When setting
-        # the scale in Windows 10 to 175%, Qt pretends its 2.0.
+        # Observations:
+        # * On Win10 + PyQt5 the ratio is a whole number (175% becomes 2).
+        # * On Win10 + PyQt6 the ratio is correct (non-integer).
         return self._subwidget.devicePixelRatioF()
 
     def get_logical_size(self):
@@ -101,7 +122,13 @@ class QtWgpuCanvas(WgpuCanvasBase, QtWidgets.QWidget):
         lsize = self._subwidget.width(), self._subwidget.height()
         lsize = float(lsize[0]), float(lsize[1])
         ratio = self._subwidget.devicePixelRatioF()
-        return round(lsize[0] * ratio), round(lsize[1] * ratio)
+        # When the ratio is not integer (qt6), we need to somehow round
+        # it. It turns out that we need to round it, but also add a
+        # small offset. Tested on Win10 with several different OS
+        # scales. Would be nice if we could ask Qt for the exact
+        # physical size! Not an issue on qt5, because ratio is always
+        # integer then.
+        return round(lsize[0] * ratio + 0.01), round(lsize[1] * ratio + 0.01)
 
     def set_logical_size(self, width, height):
         if width < 0 or height < 0:
@@ -109,7 +136,11 @@ class QtWgpuCanvas(WgpuCanvasBase, QtWidgets.QWidget):
         self.resize(width, height)  # See note on pixel ratio below
 
     def _request_draw(self):
-        self.update()
+        if not self._request_draw_timer.isActive():
+            now = time.perf_counter()
+            target_time = self._subwidget._draw_time + 1 / self._target_fps
+            wait_time = max(0, target_time - now)
+            self._request_draw_timer.start(wait_time * 1000)
 
     def close(self):
         super().close()
@@ -119,20 +150,22 @@ class QtWgpuCanvas(WgpuCanvasBase, QtWidgets.QWidget):
 
 
 class WgpuSubWidget(QtWidgets.QWidget):
-    """ The widget that actually provides the surface to render to.
-    """
+    """The widget that actually provides the surface to render to."""
 
     def __init__(self, parent):
         super().__init__(parent)
-        self.setAttribute(QtCore.Qt.WA_PaintOnScreen, True)
+        self.setAttribute(WA_PaintOnScreen, True)
         self.setAutoFillBackground(False)
+        self._draw_time = 0
 
     def paintEngine(self):  # noqa: N802 - this is a Qt method
         # https://doc.qt.io/qt-5/qt.html#WidgetAttribute-enum  WA_PaintOnScreen
         return None
 
     def paintEvent(self, event):  # noqa: N802 - this is a Qt method
+        self._draw_time = time.perf_counter()
         self.parent()._draw_frame_and_present()
 
 
+# Make available under a name that is the same for all gui backends
 WgpuCanvas = QtWgpuCanvas
